@@ -439,6 +439,9 @@ output_root (xmlTextWriterPtr xo, char *root)
     if (str)
       single_element ("windows_current_control_set", str);
     free (str);
+    i = guestfs_inspect_get_windows_group_policy (g, root);
+    if (i > 0)
+      empty_element ("windows_group_policy");
     guestfs_pop_error_handler (g);
 
     str = guestfs_inspect_get_hostname (g, root);
@@ -697,6 +700,8 @@ output_applications (xmlTextWriterPtr xo, char *root)
           single_element ("summary", apps->val[i].app2_summary);
         if (apps->val[i].app2_description && apps->val[i].app2_description[0])
           single_element ("description", apps->val[i].app2_description);
+        if (apps->val[i].app2_class && apps->val[i].app2_class[0])
+          single_element ("class", apps->val[i].app2_class);
       } end_element ();
     }
   } end_element ();
